../src/drivers/driver_nl80211_monitor.o: \
 ../src/drivers/driver_nl80211_monitor.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/eloop.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 ../src/drivers/linux_ioctl.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/radiotap_iter.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/radiotap.h \
 ../src/drivers/driver_nl80211.h ../src/drivers/nl80211_copy.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 ../src/drivers/driver.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h
