../src/utils/radiotap.o: ../src/utils/radiotap.c ../src/utils/platform.h \
 ../src/utils/includes.h ../src/utils/build_config.h \
 ../src/utils/common.h ../src/utils/os.h ../src/utils/wpa_debug.h \
 ../src/utils/wpabuf.h ../src/utils/radiotap_iter.h \
 ../src/utils/radiotap.h
