../src/common/ctrl_iface_common.o: ../src/common/ctrl_iface_common.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 ../src/common/ctrl_iface_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h
