../src/crypto/crypto_openssl.o: ../src/crypto/crypto_openssl.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 ../src/crypto/dh_group5.h ../src/crypto/sha1.h ../src/crypto/sha256.h \
 ../src/crypto/sha384.h ../src/crypto/md5.h ../src/crypto/aes_wrap.h \
 ../src/crypto/crypto.h
