main.o: main.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/eloop.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/uuid.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/random.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/tls.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/version.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/drivers/driver.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_server/eap.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_common/eap_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_server/eap_methods.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_server/tncs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/ap/hostapd.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/ap/ap_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/ip_addr.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/wpa_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/wps/wps.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/wps/wps_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/fst/fst.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/ap/vlan.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/ap/ap_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/ap/ap_drv_ops.h \
 config_file.h eap_register.h ctrl_iface.h
