../src/ap/hostapd.o: ../src/ap/hostapd.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/eloop.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/wpa_ctrl.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/hw_features_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/drivers/driver.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/radius/radius_client.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/ip_addr.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/radius/radius_das.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_server/tncs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eapol_auth/eapol_auth_sm.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eapol_auth/eapol_auth_sm_i.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/radius/radius.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/fst/fst.h \
 ../src/ap/hostapd.h ../src/ap/ap_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/wpa_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/wps/wps.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/wps/wps_defs.h \
 ../src/ap/vlan.h ../src/ap/authsrv.h ../src/ap/sta_info.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 ../src/ap/accounting.h ../src/ap/ap_list.h ../src/ap/beacon.h \
 ../src/ap/iapp.h ../src/ap/ieee802_1x.h ../src/ap/ieee802_11_auth.h \
 ../src/ap/vlan_init.h ../src/ap/wpa_auth.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/eapol_common.h \
 ../src/ap/wps_hostapd.h ../src/ap/hw_features.h \
 ../src/ap/wpa_auth_glue.h ../src/ap/ap_drv_ops.h ../src/ap/p2p_hostapd.h \
 ../src/ap/gas_serv.h ../src/ap/dfs.h ../src/ap/ieee802_11.h \
 ../src/ap/bss_load.h ../src/ap/x_snoop.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/l2_packet/l2_packet.h \
 ../src/ap/dhcp_snoop.h ../src/ap/ndisc_snoop.h ../src/ap/neighbor_db.h \
 ../src/ap/rrm.h ../src/ap/karma_handlers.h
