../src/utils/eloop.o: ../src/utils/eloop.c ../src/utils/includes.h \
 ../src/utils/build_config.h ../src/utils/common.h ../src/utils/os.h \
 ../src/utils/wpa_debug.h ../src/utils/wpabuf.h ../src/utils/trace.h \
 ../src/utils/list.h ../src/utils/eloop.h
