../src/eap_server/eap_server_peap.o: ../src/eap_server/eap_server_peap.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/sha1.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/tls.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/random.h \
 ../src/eap_server/eap_i.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_server/eap.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_common/eap_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_server/eap_methods.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_common/eap_common.h \
 ../src/eap_server/eap_tls_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_common/eap_tlv_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_common/eap_peap_common.h \
 ../src/eap_server/tncs.h
