../src/drivers/driver_nl80211_scan.o: \
 ../src/drivers/driver_nl80211_scan.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /usr/include/libnl3/netlink/genl/genl.h \
 /usr/include/libnl3/netlink/netlink.h \
 /usr/include/libnl3/netlink/netlink-compat.h \
 /usr/include/libnl3/netlink/version.h \
 /usr/include/libnl3/netlink/errno.h /usr/include/libnl3/netlink/types.h \
 /usr/include/libnl3/netlink/handlers.h \
 /usr/include/libnl3/netlink/netlink-kernel.h \
 /usr/include/libnl3/netlink/socket.h \
 /usr/include/libnl3/netlink/object.h /usr/include/libnl3/netlink/utils.h \
 /usr/include/libnl3/netlink/list.h /usr/include/libnl3/netlink/msg.h \
 /usr/include/libnl3/netlink/attr.h /usr/include/libnl3/netlink/addr.h \
 /usr/include/libnl3/netlink/data.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/eloop.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/qca-vendor.h \
 ../src/drivers/driver_nl80211.h ../src/drivers/nl80211_copy.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 ../src/drivers/driver.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h
