../src/ap/rrm.o: ../src/ap/rrm.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 ../src/ap/hostapd.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 ../src/ap/ap_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/ip_addr.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/wpa_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/wps/wps.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/wps/wps_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/fst/fst.h \
 ../src/ap/vlan.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/drivers/driver.h \
 ../src/ap/ap_drv_ops.h ../src/ap/sta_info.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/eloop.h \
 ../src/ap/neighbor_db.h ../src/ap/rrm.h
