../src/common/wpa_common.o: ../src/common/wpa_common.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/md5.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/sha1.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/sha256.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/sha384.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/aes_wrap.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/crypto.h \
 ../src/common/ieee802_11_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 ../src/common/defs.h ../src/common/wpa_common.h
