../src/radius/radius_client.o: ../src/radius/radius_client.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 ../src/radius/radius.h ../src/radius/radius_client.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/ip_addr.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/eloop.h
