../src/ap/ap_config.o: ../src/ap/ap_config.c \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/includes.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/build_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/os.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpa_debug.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/crypto/sha1.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/radius/radius_client.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/ip_addr.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/eapol_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_common/eap_wsc_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_server/eap.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_common/eap_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/eap_server/eap_methods.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/wpabuf.h \
 ../src/ap/wpa_auth.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/wpa_common.h \
 ../src/ap/sta_info.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/utils/list.h \
 ../src/ap/vlan.h ../src/ap/ap_config.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/ieee802_11_common.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/common/defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/wps/wps.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/wps/wps_defs.h \
 /root/roguehostapd/roguehostapd/hostapd-2.6/src/fst/fst.h
